Package: LSD
Version: 4.1-0
Date: 2020-06-16
Title: Lots of Superior Depictions
Author: Bjoern Schwalb [aut, cre],
	Achim Tresch [aut],
	Phillipp Torkler [ctb],
	Sebastian Duemcke [ctb],
	Carina Demel [ctb],
	Brian Ripley [ctb],
	Bill Venables [ctb]
Maintainer: Bjoern Schwalb <schwalb.bjoern@gmail.com>
Description: Create lots of colorful plots in a plethora of variations. Try the LSD demotour().
License: GPL-2 | GPL-3
LazyData: true
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-06-17 09:20:26 UTC; bschwal
Repository: CRAN
Date/Publication: 2020-06-17 09:50:18 UTC
