\name{homer}
\docType{data}
\alias{homer}
\title{homer}
\description{Homer Simpson as a list!}
\usage{homer}
\format{This list contains 31 character vectors of length 22 encoding Homer Simpson.}
\keyword{dataset}
