\name{seqs}
\docType{data}
\alias{seqs}
\title{seqs}
\description{TATAbox containing DNA-sequences!}
\usage{seqs}
\format{This list contains 20 character vectors of TATAbox containing DNA-sequences of length 30.}
\keyword{dataset}
