% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LSD.demotour.R
\name{demotour}
\alias{demotour}
\alias{LSD.demotour}
\title{LSD teaser}
\usage{
demotour()
}
\description{
A compilation of selected plot examples.
}
\examples{
demotour()
}
\seealso{
\code{\link{heatscatter}}, \code{\link{clusterplot}}, \code{\link{disco}}, \code{\link{colorpalette}}, \code{\link{daltonize}}
}
\author{
Bjoern Schwalb
}
\keyword{clusterplot}
\keyword{colorpalette}
\keyword{daltonize}
\keyword{disco}
\keyword{heatscatter}
